==> webkit2gtk_2.48.1.orig.tar.xz: webkitgtk-2.48.1/Source/WebCore/workers/service/context/ServiceWorkerDebuggable.cpp <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "ServiceWorkerDebuggable.h"

#if ENABLE(REMOTE_INSPECTOR)

#include "ServiceWorkerInspectorProxy.h"
#include "ServiceWorkerThreadProxy.h"
#include <wtf/TZoneMallocInlines.h>

namespace WebCore {

WTF_MAKE_TZONE_ALLOCATED_IMPL(ServiceWorkerDebuggable);

using namespace Inspector;

Ref<ServiceWorkerDebuggable> ServiceWorkerDebuggable::create(ServiceWorkerThreadProxy& serviceWorkerThreadProxy, const ServiceWorkerContextData& data)
{
    return adoptRef(*new ServiceWorkerDebuggable(serviceWorkerThreadProxy, data));
}

ServiceWorkerDebuggable::ServiceWorkerDebuggable(ServiceWorkerThreadProxy& serviceWorkerThreadProxy, const ServiceWorkerContextData& data)
    : m_serviceWorkerThreadProxy(serviceWorkerThreadProxy)
    , m_scopeURL(data.registration.scopeURL.string())
{
}

void ServiceWorkerDebuggable::connect(FrontendChannel& channel, bool, bool)
{
    if (RefPtr serviceWorkerThreadProxy = m_serviceWorkerThreadProxy.get())
        serviceWorkerThreadProxy->inspectorProxy().connectToWorker(channel);
}

void ServiceWorkerDebuggable::disconnect(FrontendChannel& channel)
{
    if (RefPtr serviceWorkerThreadProxy = m_serviceWorkerThreadProxy.get())
        serviceWorkerThreadProxy->inspectorProxy().disconnectFromWorker(channel);
}

void ServiceWorkerDebuggable::dispatchMessageFromRemote(String&& message)
{
    if (RefPtr serviceWorkerThreadProxy = m_serviceWorkerThreadProxy.get())
        serviceWorkerThreadProxy->inspectorProxy().sendMessageToWorker(WTFMove(message));
}

} // namespace WebCore

#endif // ENABLE(REMOTE_INSPECTOR)

==> webkit2gtk_2.50.4.orig.tar.xz: webkitgtk-2.50.4/Source/WebCore/workers/service/context/ServiceWorkerDebuggable.cpp <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "ServiceWorkerDebuggable.h"

#if ENABLE(REMOTE_INSPECTOR)

#include "ServiceWorkerInspectorProxy.h"
#include "ServiceWorkerThreadProxy.h"
#include "WorkerRunLoop.h"
#include <JavaScriptCore/RemoteInspector.h>
#include <wtf/TZoneMallocInlines.h>

namespace WebCore {

WTF_MAKE_TZONE_ALLOCATED_IMPL(ServiceWorkerDebuggable);

using namespace Inspector;

Ref<ServiceWorkerDebuggable> ServiceWorkerDebuggable::create(ServiceWorkerThreadProxy& serviceWorkerThreadProxy, const ServiceWorkerContextData& data)
{
    return adoptRef(*new ServiceWorkerDebuggable(serviceWorkerThreadProxy, data));
}

ServiceWorkerDebuggable::ServiceWorkerDebuggable(ServiceWorkerThreadProxy& serviceWorkerThreadProxy, const ServiceWorkerContextData& data)
    : m_serviceWorkerThreadProxy(serviceWorkerThreadProxy)
    , m_scopeURL(data.registration.scopeURL.string())
{
}

void ServiceWorkerDebuggable::connect(FrontendChannel& channel, bool isAutomaticInspection, bool immediatelyPause)
{
    if (RefPtr serviceWorkerThreadProxy = m_serviceWorkerThreadProxy.get()) {
#if ENABLE(REMOTE_INSPECTOR_SERVICE_WORKER_AUTO_INSPECTION)
        serviceWorkerThreadProxy->inspectorProxy().connectToWorker(channel, isAutomaticInspection, immediatelyPause);
#else
        UNUSED_PARAM(isAutomaticInspection);
        UNUSED_PARAM(immediatelyPause);
        serviceWorkerThreadProxy->inspectorProxy().connectToWorker(channel);
#endif
    }
}

void ServiceWorkerDebuggable::disconnect(FrontendChannel& channel)
{
    if (RefPtr serviceWorkerThreadProxy = m_serviceWorkerThreadProxy.get())
        serviceWorkerThreadProxy->inspectorProxy().disconnectFromWorker(channel);
}

void ServiceWorkerDebuggable::dispatchMessageFromRemote(String&& message)
{
    if (RefPtr serviceWorkerThreadProxy = m_serviceWorkerThreadProxy.get())
        serviceWorkerThreadProxy->inspectorProxy().sendMessageToWorker(WTFMove(message));
}

} // namespace WebCore

#endif // ENABLE(REMOTE_INSPECTOR)
